// %flair:license{
// This file is part of the Flair framework distributed under the
// CECILL-C License, Version 1.0.
// %flair:license}
/*!
 * \file Buffer.h
 * \brief Class defining a buffer, not for real time use
 * \author Guillaume Sanahuja, Copyright Heudiasyc UMR UTC/CNRS 7253
 * \date 2016/12/22
 * \version 4.0
 */

#ifndef BUFFER_H
#define BUFFER_H

#include <io_data.h>
#include <stdint.h>

namespace flair {
namespace core {
/*! \class Buffer
*
* \brief Class defining a buffer, not for real time use
*
*
*/
class Buffer : public io_data {
public:
  class Type : public DataType {
  public:
    Type() {}

    size_t GetSize() const {
    }
		
    std::string GetDescription() const { return "buffer"; };

  private:
  };

  /*!
  * \brief Constructor
  *
  * Construct a buffer.
  *
  * \param parent parent
  * \param name name
	* 
  */
  Buffer(const Object *parent, std::string name = "");

  /*!
  * \brief Destructor
  *
  */
  ~Buffer();

 

  Type const &GetDataType() const { return dataType; };

private:
  /*!
  * \brief Copy datas
  *
  * Reimplemented from io_data. \n
  * See io_data::CopyDatas.
  *
  * \param dst destination buffer
  */
  void CopyDatas(char *dst) const;

  Type dataType;
};

} // end namespace core
} // end namespace flair

#endif // BUFFER_H
